**Example 1: 删除规则模板**

删除规则模板

Input: 

```
tccli wedata DeleteRuleTemplate --cli-unfold-argument  \
    --ProjectId abc \
    --Ids 1
```

Output: 
```
{
    "Response": {
        "Data": true,
        "RequestId": "abc"
    }
}
```

